@@ -59,7 +59,9 @@
 #include "qgraphicsanchorlayout.h"
 #include "qgraph_p.h"
 #include "qsimplex_p.h"
-#ifndef QT_NO_GRAPHICSVIEW
+
+QT_REQUIRE_CONFIG(graphicsview);
+
 QT_BEGIN_NAMESPACE
 
 /*
@@ -71,6 +73,7 @@ QT_BEGIN_NAMESPACE
   respectively.
 */
 
+namespace QtGraphicsAnchorLayout {
 /*!
   \internal
 
@@ -86,7 +89,7 @@ struct AnchorVertex {
         : m_item(item), m_edge(edge), m_type(Normal) {}
 
     AnchorVertex()
-        : m_item(0), m_edge(Qt::AnchorPoint(0)), m_type(Normal) {}
+        : m_item(nullptr), m_edge(Qt::AnchorPoint(0)), m_type(Normal) {}
 
 #ifdef QT_DEBUG
     inline QString toString() const;
@@ -120,18 +123,18 @@ struct AnchorData : public QSimplexVariable {
     };
 
     AnchorData()
-        : QSimplexVariable(), from(0), to(0),
+        : QSimplexVariable(), from(nullptr), to(nullptr),
           minSize(0), prefSize(0), maxSize(0),
           minPrefSize(0), maxPrefSize(0),
           sizeAtMinimum(0), sizeAtPreferred(0),
-          sizeAtMaximum(0), item(0), graphicsAnchor(0),
+          sizeAtMaximum(0), item(nullptr), graphicsAnchor(nullptr),
           type(Normal), isLayoutAnchor(false),
           isCenterAnchor(false), orientation(0),
           dependency(Independent) {}
     virtual ~AnchorData();
 
     virtual void updateChildrenSizes() {}
-    void refreshSizeHints(const QLayoutStyleInfo *styleInfo = 0);
+    void refreshSizeHints(const QLayoutStyleInfo *styleInfo = nullptr);
 
 #ifdef QT_DEBUG
     void dump(int indent = 2);
@@ -196,7 +199,7 @@ struct SequentialAnchorData : public AnchorData
 #endif
     }
 
-    virtual void updateChildrenSizes() Q_DECL_OVERRIDE;
+    virtual void updateChildrenSizes() override;
     void calculateSizeHints();
 
     QVector<AnchorVertex*> m_children;          // list of vertices in the sequence
@@ -224,7 +227,7 @@ struct ParallelAnchorData : public AnchorData
 #endif
     }
 
-    virtual void updateChildrenSizes() Q_DECL_OVERRIDE;
+    virtual void updateChildrenSizes() override;
     bool calculateSizeHints();
 
     bool secondForward() const {
@@ -324,6 +327,9 @@ public:
     QSet<AnchorData *> positives;
     QSet<AnchorData *> negatives;
 };
+} // namespace QtGraphicsAnchorLayout
+using namespace QtGraphicsAnchorLayout;
+
 Q_DECLARE_TYPEINFO(GraphPath, Q_MOVABLE_TYPE);
 
 class QGraphicsAnchorLayoutPrivate;
@@ -344,6 +350,9 @@ public:
 
     void setSizePolicy(QSizePolicy::Policy policy);
 
+    static QGraphicsAnchorPrivate *get(QGraphicsAnchor *q)
+    { return q->d_func(); }
+
     QGraphicsAnchorLayoutPrivate *layoutPrivate;
     AnchorData *data;
 
@@ -393,7 +402,7 @@ public:
 
     static QGraphicsAnchorLayoutPrivate *get(QGraphicsAnchorLayout *q)
     {
-        return q ? q->d_func() : 0;
+        return q ? q->d_func() : nullptr;
     }
 
     static Qt::AnchorPoint oppositeEdge(
@@ -434,7 +443,7 @@ public:
                             Qt::AnchorPoint firstEdge,
                             QGraphicsLayoutItem *secondItem,
                             Qt::AnchorPoint secondEdge,
-                            qreal *spacing = 0);
+                            qreal *spacing = nullptr);
 
     // Helper for Anchor Manipulation methods
     void addAnchor_helper(QGraphicsLayoutItem *firstItem,
@@ -591,6 +600,5 @@ public:
 };
 
 QT_END_NAMESPACE
-#endif //QT_NO_GRAPHICSVIEW
 
 #endif
